package com.yiqi.core.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.core.domain.ClothHanger;
import com.yiqi.core.domain.vo.ClothHangerVO;

import java.util.List;

/**
 * 挂架管理Service接口
 *
 * @author ruoyi
 * @date 2023-10-05
 */
public interface IClothHangerService extends IService<ClothHanger> {
    /**
     * 查询挂架管理
     *
     * @param id 挂架管理主键
     * @return 挂架管理
     */
    public ClothHanger selectClothHangerById(Long id);

    /**
     * 查询挂架管理列表
     *
     * @param clothHangerVO 挂架管理
     * @return 挂架管理集合
     */
    public List<ClothHangerVO> selectClothHangerList(ClothHangerVO clothHangerVO);

    /**
     * 新增挂架管理
     *
     * @param clothHanger 挂架管理
     * @return 结果
     */
    public int insertClothHanger(ClothHanger clothHanger);

    /**
     * 修改挂架管理
     *
     * @param clothHanger 挂架管理
     * @return 结果
     */
    public int updateClothHanger(ClothHanger clothHanger);

    /**
     * 批量删除挂架管理
     *
     * @param ids 需要删除的挂架管理主键集合
     * @return 结果
     */
    public int deleteClothHangerByIds(Long[] ids);

    /**
     * 删除挂架管理信息
     *
     * @param id 挂架管理主键
     * @return 结果
     */
    public int deleteClothHangerById(Long id);


    /**
     * 修改挂架管理状态
     *
     * @param clothHanger 挂架管理
     * @return 结果
     */
    public int updateClothHangerStatus(ClothHanger clothHanger);

}
